# -*- coding: utf-8 -*-

# Import relevant classes for web related parameters

## Email addresses
from .email import EmailParam

## Domains
from .domain import DomainParam

## URL
from .url import UrlParam
